@@ -2,7 +2,7 @@ package Test::Builder::Formatter;
 use strict;
 use warnings;
 
-our $VERSION = '1.302084'; # TRIAL
+our $VERSION = '1.302087'; # TRIAL
 
 BEGIN { require Test2::Formatter::TAP; our @ISA = qw(Test2::Formatter::TAP) }
 
@@ -16,42 +16,41 @@ BEGIN {
     *OUT_TODO = sub() { $todo };
 }
 
-__PACKAGE__->register_event('Test::Builder::TodoDiag', 'event_todo_diag');
-
 sub init {
     my $self = shift;
     $self->SUPER::init(@_);
     $self->{+HANDLES}->[OUT_TODO] = $self->{+HANDLES}->[OUT_STD];
 }
 
-sub event_todo_diag {
-    my $self = shift;
-    my @out = $self->event_diag(@_);
-    $out[0]->[0] = OUT_TODO();
+sub plan_tap {
+    my ($self, $f) = @_;
+
+    return if $self->{+NO_HEADER};
+    return $self->SUPER::plan_tap($f);
+}
+
+sub debug_tap {
+    my ($self, $f, $num) = @_;
+    return if $self->{+NO_DIAG};
+    my @out = $self->SUPER::debug_tap($f, $num);
+    $self->redirect(\@out) if @out && $f->{about}->{package} eq 'Test::Builder::TodoDiag';
     return @out;
 }
 
-sub event_diag {
-    my $self = shift;
+sub info_tap {
+    my ($self, $f) = @_;
     return if $self->{+NO_DIAG};
-    return $self->SUPER::event_diag(@_);
+    my @out = $self->SUPER::info_tap($f);
+    $self->redirect(\@out) if @out && $f->{about}->{package} eq 'Test::Builder::TodoDiag';
+    return @out;
 }
 
-sub event_plan {
-    my $self = shift;
-    return if $self->{+NO_HEADER};
-    return $self->SUPER::event_plan(@_);
+sub redirect {
+    my ($self, $out) = @_;
+    $_->[0] = OUT_TODO for @$out;
 }
 
-sub event_ok_multiline {
-    my $self = shift;
-    my ($out, $space, @extra) = @_;
-
-    return(
-        [OUT_STD, "$out\n"],
-        map {[OUT_STD, "# $_\n"]} @extra,
-    );
-}
+sub no_subtest_space { 1 }
 
 1;
 
@@ -73,22 +72,6 @@ This is what takes events and turns them into TAP.
 
     use Test::Builder; # Loads Test::Builder::Formatter for you
 
-=head1 METHODS
-
-=over 4
-
-=item $f->event_todo_diag
-
-Additional method used to process L<Test::Builder::TodoDiag> events.
-
-=item $f->event_diag
-
-=item $f->event_plan
-
-These override the parent class methods to do nothing if C<no_header> is set.
-
-=back
-
 =head1 SOURCE
 
 The source code repository for Test2 can be found at
