@@ -2,50 +2,49 @@ package Test2::Event::Subtest;
 use strict;
 use warnings;
 
-our $VERSION = '1.302084'; # TRIAL
-
+our $VERSION = '1.302087'; # TRIAL
 
 BEGIN { require Test2::Event::Ok; our @ISA = qw(Test2::Event::Ok) }
 use Test2::Util::HashBase qw{subevents buffered subtest_id};
 
 sub init {
-	my $self = shift;
-	$self->SUPER::init();
-	$self->{+SUBEVENTS} ||= [];
-	if ($self->{+EFFECTIVE_PASS}) {
-		$_->set_effective_pass(1) for grep { $_->can('effective_pass') } @{$self->{+SUBEVENTS}};
-	}
+    my $self = shift;
+    $self->SUPER::init();
+    $self->{+SUBEVENTS} ||= [];
+    if ($self->{+EFFECTIVE_PASS}) {
+        $_->set_effective_pass(1) for grep { $_->can('effective_pass') } @{$self->{+SUBEVENTS}};
+    }
 }
 
 {
-	no warnings 'redefine';
+    no warnings 'redefine';
 
-	sub set_subevents {
-		my $self      = shift;
-		my @subevents = @_;
+    sub set_subevents {
+        my $self      = shift;
+        my @subevents = @_;
 
-		if ($self->{+EFFECTIVE_PASS}) {
-			$_->set_effective_pass(1) for grep { $_->can('effective_pass') } @subevents;
-		}
+        if ($self->{+EFFECTIVE_PASS}) {
+            $_->set_effective_pass(1) for grep { $_->can('effective_pass') } @subevents;
+        }
 
-		$self->{+SUBEVENTS} = \@subevents;
-	}
+        $self->{+SUBEVENTS} = \@subevents;
+    }
 
-	sub set_effective_pass {
-		my $self = shift;
-		my ($pass) = @_;
+    sub set_effective_pass {
+        my $self = shift;
+        my ($pass) = @_;
 
-		if ($pass) {
-			$_->set_effective_pass(1) for grep { $_->can('effective_pass') } @{$self->{+SUBEVENTS}};
-		}
-		elsif ($self->{+EFFECTIVE_PASS} && !$pass) {
-			for my $s (grep { $_->can('effective_pass') } @{$self->{+SUBEVENTS}}) {
-				$_->set_effective_pass(0) unless $s->can('todo') && defined $s->todo;
-			}
-		}
+        if ($pass) {
+            $_->set_effective_pass(1) for grep { $_->can('effective_pass') } @{$self->{+SUBEVENTS}};
+        }
+        elsif ($self->{+EFFECTIVE_PASS} && !$pass) {
+            for my $s (grep { $_->can('effective_pass') } @{$self->{+SUBEVENTS}}) {
+                $_->set_effective_pass(0) unless $s->can('todo') && defined $s->todo;
+            }
+        }
 
-		$self->{+EFFECTIVE_PASS} = $pass;
-	}
+        $self->{+EFFECTIVE_PASS} = $pass;
+    }
 }
 
 sub summary {
@@ -58,12 +57,42 @@ sub summary {
         $name .= " (TODO: $todo)";
     }
     elsif (defined $todo) {
-        $name .= " (TODO)"
+        $name .= " (TODO)";
     }
 
     return $name;
 }
 
+sub facet_data {
+    my $self = shift;
+
+    my $out = $self->SUPER::facet_data();
+
+    $out->{parent} = {
+        hid      => $self->subtest_id,
+        children => [map {$_->facet_data} @{$self->{+SUBEVENTS}}],
+        buffered => $self->{+BUFFERED},
+    };
+
+    return $out;
+}
+
+sub add_amnesty {
+    my $self = shift;
+
+    for my $am (@_) {
+        $am = {%$am} if ref($am) ne 'ARRAY';
+        $am = Test2::EventFacet::Amnesty->new($am);
+
+        push @{$self->{+AMNESTY}} => $am;
+
+        for my $e (@{$self->{+SUBEVENTS}}) {
+            $e->add_amnesty($am->clone(inherited => 1));
+        }
+    }
+}
+
+
 1;
 
 __END__
