@@ -2,7 +2,7 @@ package Test2::Hub::Interceptor;
 use strict;
 use warnings;
 
-our $VERSION = '1.302084'; # TRIAL
+our $VERSION = '1.302087'; # TRIAL
 
 
 use Test2::Hub::Interceptor::Terminator();
@@ -10,10 +10,18 @@ use Test2::Hub::Interceptor::Terminator();
 BEGIN { require Test2::Hub; our @ISA = qw(Test2::Hub) }
 use Test2::Util::HashBase;
 
+sub init {
+    my $self = shift;
+    $self->SUPER::init;
+    $self->{+NESTED} = 0;
+}
+
 sub inherit {
     my $self = shift;
     my ($from, %params) = @_;
 
+    $self->{+NESTED} = 0;
+
     if ($from->{+IPC} && !$self->{+IPC} && !exists($params{ipc})) {
         my $ipc = $from->{+IPC};
         $self->{+IPC} = $ipc;
